## Dataset Attribution
The inventory was extracted from a lexicon published by Nicolas, Bai & Fiske.
The use is governed by terms of use on `osf.io`, which at the time "grant its
users a perpetual, irrevocable, worldwide, royalty-free license to use, publicly
display, and publicly perform" the contents from this folder.

- Original Paper: _Automated Dictionary Creation for Analyzing Text: An
Illustration from Stereotype Content_ [[Nicolas, Bai & Fiske 2019](https://osf.io/preprints/psyarxiv/afm8k_v1)].
- Data Repository: [osf.io](https://osf.io/yx45f/)
- Changes Made: We have extracted words from `finalwordlist R 050418.csv` that
had "high" `Dir` attributy. The words from "Ability" and "Agency" dictionaries
were assigned as male, the words from "Sociability" and "Morality" as female.
This reflects the stereotypical perception of men and women on the
warmth-competence stereotype content model. Men are perceived as competent,
while women are perceived as warm.